# Upstream name
%global srcname Flask-Migrate

%bcond_without tests
# The following dependencies are currently missing on EPEL7:
#   - python36-alembic
#   - python36-flask-script
#   - python36-flask-sqlalchemy
# …and given how far we are into the EPEL7 lifecycle, this is unlikely to ever
# be remedied.
%bcond_with python3

# Name used in egg-info
%global eggname %(\
  awk -vn='%{srcname}' 'BEGIN { gsub(/-/, "_", n); print n }')
# Name of importable Python package
%global modname %(\
  awk -vn='%{srcname}' 'BEGIN { gsub(/-/, "_", n); print tolower(n) }')
# Name used in RPM package names
%global rpmname %{py_dist_name %{srcname}}

Name:               python-%{rpmname}
Version:            2.0.4
Release:            1%{?dist}
Summary:            SQLAlchemy database migrations for Flask applications using Alembic

License:            MIT
URL:                https://github.com/miguelgrinberg/%{srcname}/
Source0:            %{pypi_source}
BuildArch:          noarch

%global min_flask 0.9
%global min_flask_sqlalchemy 1.0
%global min_alembic 0.6
%global min_flask_script 0.6

%global common_description %{expand:
%{summary}}.

%description %{common_description}


%package -n python2-%{rpmname}
Summary:            %{summary}
%{?python_provide:%python_provide python2-%{rpmname}}

BuildRequires:      python2-devel
BuildRequires:      python2-setuptools
BuildRequires:      python-flask >= %{min_flask}
BuildRequires:      python2-flask-sqlalchemy >= %{min_flask_sqlalchemy}
BuildRequires:      python-alembic >= %{min_alembic}
BuildRequires:      python-flask-script >= %{min_flask_script}

Requires:           python-flask >= %{min_flask}
Requires:           python2-flask-sqlalchemy >= %{min_flask_sqlalchemy}
Requires:           python-alembic >= %{min_alembic}
Requires:           python-flask-script >= %{min_flask_script}

%description -n python2-%{rpmname} %{common_description}


%if %{with python3}
%package -n python%{python3_pkgversion}-%{rpmname}
Summary:            %{summary}
%{?python_provide:%python_provide python%{python3_pkgversion}-%{rpmname}}

BuildRequires:      python%{python3_pkgversion}-devel
BuildRequires:      python%{python3_pkgversion}-setuptools
BuildRequires:      python%{python3_pkgversion}-flask >= %{min_flask}
BuildRequires:      python%{python3_pkgversion}-flask-sqlalchemy >= %{min_flask_sqlalchemy}
BuildRequires:      python%{python3_pkgversion}-alembic >= %{min_alembic}
BuildRequires:      python%{python3_pkgversion}-flask-script >= %{min_flask_script}

Requires:           python%{python3_pkgversion}-flask >= %{min_flask}
Requires:           python%{python3_pkgversion}-flask-sqlalchemy >= %{min_flask_sqlalchemy}
Requires:           python%{python3_pkgversion}-alembic >= %{min_alembic}
Requires:           python%{python3_pkgversion}-flask-script >= %{min_flask_script}

%description -n python%{python3_pkgversion}-%{rpmname} %{common_description}
%endif


%prep
%autosetup -n %{srcname}-%{version}
# Fix unwanted executable bits inside the Python package (fixed upstream in a
# later release)
find '%{modname}' -type f -perm /0111 -execdir chmod -v a-x '{}' '+'
# Fix unversioned Python command
sed -r -i 's/(python)( |$)/\12\2/g' tests/*.py

# No Flask CLI (/usr/bin/flask) is packaged in EPEL7:
rm -vf tests/test_*_flaskcli.py


%build
%py2_build
%if %{with python3}
%py3_build
%endif


%install
%py2_install
%if %{with python3}
%py3_install
%endif


%check
%if %{with tests}
env PYTHONPATH="${PYTHONPATH:-%{buildroot}%{python2_sitelib}}" \
    PYTHONDONTWRITEBYTECODE=1 \
    %{__python2} -m unittest discover -v
%if %{with python3}
sed -r -i '1{s/(python)2/\13/}' tests/*.py
env PYTHONPATH="${PYTHONPATH:-%{buildroot}%{python3_sitelib}}" \
    PYTHONDONTWRITEBYTECODE=1 \
    %{__python3} -m unittest discover -v
%endif
%else
echo 'Tests are disabled'
%endif


%files -n python2-%{rpmname}
%license LICENSE
%doc README.md
%{python2_sitelib}/%{modname}/
%{python2_sitelib}/%{eggname}-%{version}*


%if %{with python3}
%files -n python%{python3_pkgversion}-%{rpmname}
%license LICENSE
%doc README.md
%{python3_sitelib}/%{modname}/
%{python3_sitelib}/%{eggname}-%{version}*
%endif


%changelog
* Tue Jun 01 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.4-1
- Update to 2.0.4, the last release in the 2.0.x series

* Mon May 31 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 2.0.0-4
- Replace %%modname with a group of name macros and use them in more places
- Change URL from PyPI to GitHub, and HTTP to HTTPS
- Use %%pypi_source macro
- Adjust whitespace to personal preference
- Drop %%python3_pkgversion and %%python_provide macros, only needed in EPEL
- Remove executable bits from files in the Python package
- Version the BR’s and manual Requires
- Run the tests
- Change Python 3 conditional macro to a modern build conditional and use
  %%python3_pkgversion macro (but still do not try to build for Python 3 due to
  missing dependencies)
- Remove cruft for EL6 and older
- Make the common description a macro

* Wed Jan 18 2017 Ralph Bean <rbean@redhat.com> - 2.0.0-3
- Conditionalize deps for EL7.

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 2.0.0-2
- Rebuild for Python 3.6

* Wed Aug 10 2016 Ralph Bean <rbean@redhat.com> - 2.0.0-1
- Initial package for Fedora!  \ó/
